﻿/*
  Antenna House PDF Tool API V6.0
  .Net Interface sample program

  概要：レイヤーの描画　指定したページにもう一つのPDFを重ねて表示します。

  Copyright (C) 2018- Antenna House, Inc. All rights reserved.
  Antenna House is a trademark of [Antenna House, Inc.]

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
*/

using PdfTkNet;
using System;

namespace cookbook
{
    public class DrawLayerSetPage
    {
        // そのクラスのusageを表示する関数
        private static void printUsage()
        {
            Console.WriteLine("usage: DrawLayerSetPage in-pdf-file out-pdf-file" +
                               " page-num insert-pdf-file page-num-to-insert");
        }

        /**
         * @param args the command line arguments
         */
        public static void Main(String[] args)
        {
            if (args.Length < 5)
            {
                printUsage();
                return;
            }

            try
            {
                using (PtlParamInput inputFile = new PtlParamInput(args[0]))
                using (PtlParamOutput outputFile = new PtlParamOutput(args[1]))
                using (PtlPDFDocument doc = new PtlPDFDocument())
                {
                    // DFファイルをロードします。
                    doc.load(inputFile);
                    // コマンドライン引数の判定
                    int pageToAdd = int.Parse(args[2]);
                    int numPages = doc.getPageCount();
                    Console.WriteLine("ページ数：" + numPages);
                    if ((numPages < 0) || (numPages < pageToAdd))
                    {
                        Console.WriteLine("page-numは入力PDFの全ページ数よりも小さい正の値を" +
                                           "指定してください。");
                        return;
                    }
                    String insertPDFPath = args[3];
                    int insertPageNum = int.Parse(args[4]);

                    using (PtlPages pages = doc.getPages())
                    { // ページコンテナの取得
                      // ページコンテナが空かどうか
                        if (pages.isEmpty())
                        {
                            Console.WriteLine("ページコンテナが空");
                            return;
                        }

                        // ページの取得(パラメータindexは0が先頭のため1を引く)
                        using (PtlPage page = pages.get(pageToAdd - 1))
                        {
                            drawLayer(page, insertPDFPath, insertPageNum); //レイヤーの描画
                        }
                    }

                    // ファイルに保存します。
                    doc.save(outputFile);
                }
            }
            catch (PtlException pex)
            {
                Console.WriteLine("PtlException : ErrorCode = " + pex.getErrorCode() +
                                   "\n  " + pex.getErrorMessage());
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
                Console.WriteLine(ex.StackTrace);
            }
            finally
            {
                Console.WriteLine("-- 完了 --");
            }
        }

        public static void drawLayer(PtlPage page, String insertPDFPath, int insertPageNum)
        {
            using (PtlSize pageSize = page.getSize())    // ページサイズ
            using (PtlContent content = page.getContent()) // ページコンテントの取得
            using (PtlPDFDocument docToInsert = new PtlPDFDocument())
            //挿入するPDF
            using (PtlParamInput inputFileToInsert = new PtlParamInput(insertPDFPath))
            // 描画矩形の指定（PDFいっぱいに指定）
            using (PtlRect rect = new PtlRect(0.0f,
                                       0.0f,
                                       pageSize.getWidth(),
                                       pageSize.getHeight()))
            {
                // PDFファイルをロードします。
                docToInsert.load(inputFileToInsert);

                using (PtlPages pagesToInsert = docToInsert.getPages())
                { // ページコンテナの取得
                  // ページコンテナが空かどうか
                    if (pagesToInsert.isEmpty())
                    {
                        Console.WriteLine("ページコンテナが空");
                        return;
                    }

                    // ページの取得(パラメータindexは0が先頭のため1を引く)
                    // レイヤーのパラメーターの取得
                    using (PtlPage pageInsert = pagesToInsert.get(insertPageNum - 1))
                    using (PtlParamDrawLayer param = new PtlParamDrawLayer())
                    {
                        // レイヤーにするページ
                        param.setPage(pageInsert);
                        // レイヤーの名前
                        param.setName("Layer1");
                        // レイヤーを前面に
                        param.setZorder(PtlParamDrawLayer.ZORDER.ZORDER_FRONT);
                        // レイヤーを表示
                        param.setShow(PtlParamDrawLayer.SHOW.SHOW_ON);
                        // レイヤーの描画
                        content.drawLayer(rect, PtlContent.ALIGN.ALIGN_CENTER, param);
                    }
                }
            }
        }
    }
}
